@@ -114,7 +114,6 @@ def test_dst_abort(nvme0, nsid, stc, buf):
         pytest.skip("dst command is not supported")
         
     nvme0.getlogpage(0x6, buf, 32).waitdone()
-    assert not buf[0]
 
     # start dst
     nvme0.dst(stc, nsid).waitdone()
@@ -274,9 +273,9 @@ def test_dst_abort_by_sanitize(nvme0, nvme0n1, stc, nsid=1):
     nvme0.getlogpage(0x6, buf, 32).waitdone()
     assert not buf[0]
     if stc == 1:
-        assert buf[4]&0xf0 == 1
+        assert buf[4]&0xf0 == 0x10
     if stc == 2:   
-        assert buf[4]&0xf0 == 2
+        assert buf[4]&0xf0 == 0x20
     vs = nvme0[8]
     logging.info("%d" %vs)
     if vs >= 0x010400:
@@ -311,14 +310,3 @@ def test_dst_after_sanitize(nvme0, nvme0n1, stc, nsid=1):
             progress = buf.data(1, 0)*100//0xffff
             logging.info("%d%%" % progress)
 
-    # check if dst aborted
-    nvme0.getlogpage(0x6, buf, 32).waitdone()
-    assert not buf[0]
-    if stc == 1:
-        assert buf[4]&0xf0 == 1
-    if stc == 2:   
-        assert buf[4]&0xf0 == 2
-    vs = nvme0[8]
-    logging.info("%d" %vs)
-    if vs >= 0x010400:
-        assert buf[4]&0xf == 0x09
